@@ -9,11 +9,17 @@ import (
 
 	"github.com/ProtonMail/go-crypto/openpgp/ecdh"
 	"github.com/ProtonMail/go-crypto/openpgp/eddsa"
+	"github.com/ProtonMail/gopenpgp/v3/profile"
 
 	"github.com/stretchr/testify/assert"
 )
 
 const testTime = 1557754627 // 2019-05-13T13:37:07+00:00
+const testMessage = "Hello world!"
+
+var testPGP *PGPHandle
+var testProfiles []*profile.Custom
+var testProfileNames []string
 
 func readTestFile(name string, trimNewlines bool) string {
 	data, err := os.ReadFile("testdata/" + name) //nolint
@@ -27,8 +33,11 @@ func readTestFile(name string, trimNewlines bool) string {
 }
 
 func init() {
-	UpdateTime(testTime) // 2019-05-13T13:37:07+00:00
-
+	testPGP = PGP()
+	testPGP.defaultTime = NewConstantClock(testTime) // 2019-05-13T13:37:07+00:00
+	testProfiles = []*profile.Custom{profile.Default(), profile.RFC4880(), profile.RFC9580()}
+	testProfileNames = []string{"Default", "RFC4880", "RFC9580"}
+	initEncDecTest()
 	initGenerateKeys()
 	initArmoredKeys()
 	initKeyRings()
